@@ -49,38 +49,38 @@ class HGClientTestSetups(unittest.TestCase):
 
         directory = tempfile.mkdtemp()
         self.directories = dict(setUp=directory)
-        remote_path = os.path.join(directory, "remote")
-        os.makedirs(remote_path)
+        self.remote_path = os.path.join(directory, "remote")
+        os.makedirs(self.remote_path)
 
         # create a "remote" repo
-        subprocess.check_call("hg init", shell=True, cwd=remote_path)
-        subprocess.check_call("touch fixed.txt", shell=True, cwd=remote_path)
-        subprocess.check_call("hg add fixed.txt", shell=True, cwd=remote_path)
-        subprocess.check_call("hg commit -m initial", shell=True, cwd=remote_path)
+        subprocess.check_call("hg init", shell=True, cwd=self.remote_path)
+        subprocess.check_call("touch fixed.txt", shell=True, cwd=self.remote_path)
+        subprocess.check_call("hg add fixed.txt", shell=True, cwd=self.remote_path)
+        subprocess.check_call("hg commit -m initial", shell=True, cwd=self.remote_path)
         
-        po = subprocess.Popen("hg log --template '{node|short}' -l1", shell=True, cwd=remote_path, stdout=subprocess.PIPE)
+        po = subprocess.Popen("hg log --template '{node|short}' -l1", shell=True, cwd=self.remote_path, stdout=subprocess.PIPE)
         self.local_version_init = po.stdout.read().rstrip("'").lstrip("'")
         # in hg, tagging creates an own changeset, so we need to fetch version before tagging
-        subprocess.check_call("hg tag test_tag", shell=True, cwd=remote_path)
+        subprocess.check_call("hg tag test_tag", shell=True, cwd=self.remote_path)
 
         
         # files to be modified in "local" repo
-        subprocess.check_call("touch modified.txt", shell=True, cwd=remote_path)
-        subprocess.check_call("touch modified-fs.txt", shell=True, cwd=remote_path)
-        subprocess.check_call("hg add modified.txt modified-fs.txt", shell=True, cwd=remote_path)
-        subprocess.check_call("hg commit -m initial", shell=True, cwd=remote_path)
-        po = subprocess.Popen("hg log --template '{node|short}' -l1", shell=True, cwd=remote_path, stdout=subprocess.PIPE)
+        subprocess.check_call("touch modified.txt", shell=True, cwd=self.remote_path)
+        subprocess.check_call("touch modified-fs.txt", shell=True, cwd=self.remote_path)
+        subprocess.check_call("hg add modified.txt modified-fs.txt", shell=True, cwd=self.remote_path)
+        subprocess.check_call("hg commit -m initial", shell=True, cwd=self.remote_path)
+        po = subprocess.Popen("hg log --template '{node|short}' -l1", shell=True, cwd=self.remote_path, stdout=subprocess.PIPE)
         self.local_version_second = po.stdout.read().rstrip("'").lstrip("'")
         
-        subprocess.check_call("touch deleted.txt", shell=True, cwd=remote_path)
-        subprocess.check_call("touch deleted-fs.txt", shell=True, cwd=remote_path)
-        subprocess.check_call("hg add deleted.txt deleted-fs.txt", shell=True, cwd=remote_path)
-        subprocess.check_call("hg commit -m modified", shell=True, cwd=remote_path)
-        po = subprocess.Popen("hg log --template '{node|short}' -l1", shell=True, cwd=remote_path, stdout=subprocess.PIPE)
+        subprocess.check_call("touch deleted.txt", shell=True, cwd=self.remote_path)
+        subprocess.check_call("touch deleted-fs.txt", shell=True, cwd=self.remote_path)
+        subprocess.check_call("hg add deleted.txt deleted-fs.txt", shell=True, cwd=self.remote_path)
+        subprocess.check_call("hg commit -m modified", shell=True, cwd=self.remote_path)
+        po = subprocess.Popen("hg log --template '{node|short}' -l1", shell=True, cwd=self.remote_path, stdout=subprocess.PIPE)
         self.local_version = po.stdout.read().rstrip("'").lstrip("'")
 
         self.local_path = os.path.join(directory, "local")
-        self.local_url = remote_path
+        self.local_url = self.remote_path
         
 
     @classmethod
@@ -172,7 +172,14 @@ class HGClientTest(HGClientTestSetups):
 
         self.assertTrue(client.update(''))
         self.assertEqual(client.get_version(), self.local_version)
-       
+        
+    def testDiffClean(self):
+        client = HgClient(self.remote_path)
+        self.assertEquals('', client.get_diff())
+
+    def testStatusClean(self):
+        client = HgClient(self.remote_path)
+        self.assertEquals('', client.get_status())       
 
 class HGDiffStatClientTest(HGClientTestSetups):
 
@@ -207,7 +214,7 @@ class HGDiffStatClientTest(HGClientTestSetups):
         client = HgClient(self.local_path)
         self.assertTrue(client.path_exists())
         self.assertTrue(client.detect_presence())
-        self.assertEquals('diff --git ./added.txt ./added.txt\nnew file mode 100644\n--- /dev/null\n+++ ./added.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\ndiff --git ./deleted.txt ./deleted.txt\ndeleted file mode 100644\ndiff --git ./modified-fs.txt ./modified-fs.txt\n--- ./modified-fs.txt\n+++ ./modified-fs.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\ndiff --git ./modified.txt ./modified.txt\n--- ./modified.txt\n+++ ./modified.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n', client.get_diff())
+        self.assertEquals('diff --git ./added.txt ./added.txt\nnew file mode 100644\n--- /dev/null\n+++ ./added.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\ndiff --git ./deleted.txt ./deleted.txt\ndeleted file mode 100644\ndiff --git ./modified-fs.txt ./modified-fs.txt\n--- ./modified-fs.txt\n+++ ./modified-fs.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\ndiff --git ./modified.txt ./modified.txt\n--- ./modified.txt\n+++ ./modified.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file', client.get_diff())
 
     def test_diff_relpath(self):
 
@@ -215,7 +222,7 @@ class HGDiffStatClientTest(HGClientTestSetups):
         self.assertTrue(client.path_exists())
         self.assertTrue(client.detect_presence())
 
-        self.assertEquals('diff --git local/added.txt local/added.txt\nnew file mode 100644\n--- /dev/null\n+++ local/added.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\ndiff --git local/deleted.txt local/deleted.txt\ndeleted file mode 100644\ndiff --git local/modified-fs.txt local/modified-fs.txt\n--- local/modified-fs.txt\n+++ local/modified-fs.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\ndiff --git local/modified.txt local/modified.txt\n--- local/modified.txt\n+++ local/modified.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n', client.get_diff(basepath=os.path.dirname(self.local_path)))
+        self.assertEquals('diff --git local/added.txt local/added.txt\nnew file mode 100644\n--- /dev/null\n+++ local/added.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\ndiff --git local/deleted.txt local/deleted.txt\ndeleted file mode 100644\ndiff --git local/modified-fs.txt local/modified-fs.txt\n--- local/modified-fs.txt\n+++ local/modified-fs.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\ndiff --git local/modified.txt local/modified.txt\n--- local/modified.txt\n+++ local/modified.txt\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file', client.get_diff(basepath=os.path.dirname(self.local_path)))
 
     def test_get_version_modified(self):
         client = HgClient(self.local_path)
@@ -225,19 +232,19 @@ class HGDiffStatClientTest(HGClientTestSetups):
         client = HgClient(self.local_path)
         self.assertTrue(client.path_exists())
         self.assertTrue(client.detect_presence())
-        self.assertEquals('M modified-fs.txt\nM modified.txt\nA added.txt\nR deleted.txt\n! deleted-fs.txt\n', client.get_status())
+        self.assertEquals('M modified-fs.txt\nM modified.txt\nA added.txt\nR deleted.txt\n! deleted-fs.txt', client.get_status())
 
     def test_status_relpath(self):
         client = HgClient(self.local_path)
         self.assertTrue(client.path_exists())
         self.assertTrue(client.detect_presence())
-        self.assertEquals('M local/modified-fs.txt\nM local/modified.txt\nA local/added.txt\nR local/deleted.txt\n! local/deleted-fs.txt\n', client.get_status(basepath=os.path.dirname(self.local_path)))
+        self.assertEquals('M local/modified-fs.txt\nM local/modified.txt\nA local/added.txt\nR local/deleted.txt\n! local/deleted-fs.txt', client.get_status(basepath=os.path.dirname(self.local_path)))
 
     def testStatusUntracked(self):
         client = HgClient(self.local_path)
         self.assertTrue(client.path_exists())
         self.assertTrue(client.detect_presence())
-        self.assertEquals('M modified-fs.txt\nM modified.txt\nA added.txt\nR deleted.txt\n! deleted-fs.txt\n? added-fs.txt\n', client.get_status(untracked=True))
+        self.assertEquals('M modified-fs.txt\nM modified.txt\nA added.txt\nR deleted.txt\n! deleted-fs.txt\n? added-fs.txt', client.get_status(untracked=True))
 
 
     def test_hg_diff_path_change_None(self):
